@@ -2,6 +2,7 @@ import os
 import logging
 from kopf.engines import loggers
 
+# default log level and format
 logger = logging.getLogger(__name__)
 __handler = logging.StreamHandler()
 __handler.setFormatter(loggers.make_formatter())
@@ -9,6 +10,7 @@ logger.addHandler(__handler)
 logger.setLevel(int(os.environ.get("LOGLEVEL", logging.INFO)))
 
 
+# default auri
 def set_default_gvr():
     if "GROUP" not in os.environ:
         os.environ["GROUP"] = "nil.digi.dev"
@@ -24,16 +26,20 @@ def set_default_gvr():
 
 set_default_gvr()
 
+
+# digi modules
 from digi import (
     on,
     util,
     view,
     filter,
 )
-
 from digi.main import run
+from digi.reconcile import rc
+auri = (rc.g, rc.v, rc.r, rc.n, rc.ns)
 
 __all__ = [
     "on", "util", "view", "filter",
-    "run", "logger",
+    "run", "logger", "auri"
+
 ]
